//
//  The BUTTON CLASS
//
// Although Javascript does not support private members, you shouldn't
// access any of the member variables.  Instead, you should use the
// methods provided.
//
// getTitle() will return the correct title or label
// getLink() will return the correct url for this button
// getImage() will return the correct image for this button
// isSeparator() will return true if this button is actually a Separator
//               (The Yahoo Companion feed doesn't distinguish between button
//                and separator.)
// isSearchToggle() will return true if this button is the special Search
//                Toggle button.  (The little magnifying glass.)
//
// $Id: class_Button.js,v 1.3 2004/01/27 17:03:48 burgner Exp $

function Button(title,raw)
{
    this.raw = raw;
    this.title = title;
    this.type = "";
    this.img = "";
    this.link = "";
    this.parse(this.raw);
}

// getTitle will return the proper title for a button.

Button.prototype.getTitle = function()
{
    // the Logo has no title
    if(this.type == "logo")
        return null;
    
    if(this.isSearchToggle())
        return "";
    return this.title;
}

Button.prototype.getImage = function()
{
    if(this.isSearchToggle())
        return "chrome://yahootoolbar/content/icons/mglass.gif";
	else
        return this.img;
}

Button.prototype.getLink = function()
{
    return this.link;
}

Button.prototype.isSeparator = function()
{
    if(this.type == "vsep")
        return true;
    else
        return false;
}

Button.prototype.isSearchToggle = function()
{
    if(this.title == "stoggle")
        return true;
    else
        return false;
}

// parse takes a string which must contain the button data encoded.
// This should only be called to construct a button.
Button.prototype.parse = function(txt)
{
    var end = txt.indexOf('\x18');
    this.type = txt.substr(0, end);
    this.link = this.extractLink(txt.substr(end+1));
    
    // if buttonType has a .bmp in it, then it is actually an image.
    // need to find those images on the yimg servers...
    // if the buttonType is empty, and the title is "Sign On", the use title

    switch(this.type)
    {
        case "logo":
            this.img = "chrome://yahootoolbar/content/icons/y.gif";
            break;
        case "vsep":
            // vsep is a ToolBarSeparator!
            this.img = "";
            break;
        // these bmps can be found in C:\Program Files\Yahoo!\Companion\Icons
        case "tot.bmp": // the Y! image
            this.img = "chrome://yahootoolbar/content/icons/ylogo.gif";
            break;
        case "01c.bmp": // the My Yahoo image
            this.img = "chrome://yahootoolbar/content/icons/my16.gif";
            break;
        case "02c.bmp": // the Mail image
            this.img = "chrome://yahootoolbar/content/icons/env.gif";
            break;
	case "03c.bmp": // the Calendar image
            this.img = "chrome://yahootoolbar/content/icons/cal.gif";
            break;
        case "04c.bmp": // the Address Book image
            this.img = "chrome://yahootoolbar/content/icons/04c.gif";
            break;
        case "05c.bmp": // the Mail image
            this.img = "chrome://yahootoolbar/content/icons/bm.gif";
            break;
        case "06c.bmp": // unused
            this.img = "";
            break;  
	case "07c.bmp" : // the News image
            this.img = "chrome://yahootoolbar/content/icons/nws_ico.gif";
            break;
        case "08c.bmp" : // the Sports image
            this.img = "chrome://yahootoolbar/content/icons/08c.gif";
            break;
        case "09c.bmp" : // the Weather image
            this.img = "chrome://yahootoolbar/content/icons/wea.gif";
            break;
        case "10c.bmp" : // the Finance image
            this.img = "chrome://yahootoolbar/content/icons/fi_ico.gif";
            break;
        case "11c.bmp": // the Shopping image
            this.img = "chrome://yahootoolbar/content/icons/shp_ico.gif";
            break;
        case "16c.bmp": // the Movies image
            this.img = "chrome://yahootoolbar/content/icons/kino.gif";
            break;
        case "17c.bmp": // the TV image
            this.img = "chrome://yahootoolbar/content/icons/tv.gif";
            break;
        case "18c.bmp": // the Music image
            this.img = "chrome://yahootoolbar/content/icons/mus.gif";
            break;
        case "19c.bmp": // the Games image
            this.img = "chrome://yahootoolbar/content/icons/ga_ico.gif";
            break;
        case "23c.bmp": // unused
            this.img = "";
            break;
        case "25c.bmp": // the Yellow Pages image
            this.img = "chrome://yahootoolbar/content/icons/25c.gif";
            break;
        case "27c.bmp": // the Maps image
            this.img = "chrome://yahootoolbar/content/icons/map.gif";
            break;
        case "30c.bmp": // the Travel image
            this.img = "chrome://yahootoolbar/content/icons/tra.gif";
            break;
        case "36c.bmp": // the Briefcase image
            this.img = "chrome://yahootoolbar/content/icons/36c.gif";
            break;
        case "43c.bmp": // the Mobile image
            this.img = "chrome://yahootoolbar/content/icons/mobl.gif";
            break;
        case "44c.bmp": // the Entertainment image
            this.img = "chrome://yahootoolbar/content/icons/44c.gif";
            break;
        case "48c.bmp": // the Logout image
            this.img = "chrome://yahootoolbar/content/icons/lgout.gif";
            break;
        case "50c.bmp": // the Messenger image
            this.img = "chrome://yahootoolbar/content/icons/50c.gif";
            break;
        case "52c.bmp": // the Personals image
            this.img = "chrome://yahootoolbar/content/icons/prsls.gif";
            break;
        case "53c.bmp": // the Photos image
            this.img = "chrome://yahootoolbar/content/icons/53c.gif";
            break;
        case "54c.bmp": // the Auctions image 
            this.img = "chrome://yahootoolbar/content/icons/actns.gif";
            break;
        case "ad_bigsale.bmp": // the Ad Bigsales image 
            this.img = "chrome://yahootoolbar/content/icons/wre.gif";
            break;
        case "dir.bmp": // the Yahoo! Folder image
            this.img = "chrome://yahootoolbar/content/icons/dir.gif";
            break; 
        case "mov_de.bmp": // the German Movies image  
            this.img = "chrome://yahootoolbar/content/icons/kino.gif";
            break; 
        case "tb_srch.bmp": // the Search image  
            this.img = "chrome://yahootoolbar/content/icons/tbsr.gif";
            break;  
        case "nba.bmp": // the NBA image  
            this.img = "chrome://yahootoolbar/content/icons/nba.gif";
            break; 
        case "ar_59c.bmp": // the Horoscope image  
            this.img = "chrome://yahootoolbar/content/icons/ar_59c.gif";
            break; 
        case "cbb.bmp": // the CBB image  
            this.img = "chrome://yahootoolbar/content/icons/cbb.gif";
            break;    
        case "tra.bmp": // the Travel image (2nd)
            this.img = "chrome://yahootoolbar/content/icons/tra.gif";
            break;
        case "swi.bmp": // the SWI image 
            this.img = "chrome://yahootoolbar/content/icons/swi.gif";
            break; 
        case "srch_hi.bmp": // the Search Highlight image 
            this.img = "chrome://yahootoolbar/content/icons/srch_hi.gif";
            break;
        case "qsyma.bmp": // the qsyma image 
            this.img = "chrome://yahootoolbar/content/icons/qsyma.gif";
            break;
        case "qsy.bmp": // the qsy image 
            this.img = "chrome://yahootoolbar/content/icons/qsy.gif";
            break;
        case "qsim.bmp": // the qsim image 
            this.img = "chrome://yahootoolbar/content/icons/qsim.gif";
            break;
        case "qsbm.bmp": // the qsbm image 
            this.img = "chrome://yahootoolbar/content/icons/qsbm.gif";
            break;
        case "pub_s2.bmp": // the pub_s2 image 
            this.img = "chrome://yahootoolbar/content/icons/pub_s2.gif";
            break;
        case "fifa2.bmp": // the Fifa image 
            this.img = "chrome://yahootoolbar/content/icons/fifa2.gif";
            break;
        case "nfl.bmp": // the NFL image 
            this.img = "chrome://yahootoolbar/content/icons/nfl.gif";
            break;
        case "mlb.bmp": // the MLB  image 
            this.img = "chrome://yahootoolbar/content/icons/mlb.gif";
            break;         
	default:
            this.img = "";
            break;
    }
}

Button.prototype.extractLink = function(txt)
{
    var link = "";
    // we need to skip ahead 3 ^As
    var i=0;
    var offset = 0;
    var buffer = txt;
    for( ; i < 3; i++)
    {
        var a = buffer.indexOf('\x01',offset);
        if(a == -1)
            break;
        else
        {
            offset = a+1;
        }
    }
    // if i == 3, then we did it...
    if(i!=3)
    {
        return link;
    }
    // now we need to find the string to the next ^X
    // but the first char is always a %... so just remove it.
    var end = buffer.indexOf('\x18',offset);
    link = buffer.substr(offset,(end - offset))
    if(link.substr(0,1) == "%")
        link = link.substr(1);
    return link;
}

